@@ -2,7 +2,7 @@
 Cucumber result to Jira Xray Test repository
 
 """
-__version__ = "0.5.0"
+__version__ = "0.5.1"
 
 
 import datetime
@@ -57,7 +57,7 @@ class CuJiraX:
 
 
     def set_testexecution_name(self, testexecution_name: str):
-        self.testexecution_name = testexecution_name
+        self.testexecution_name = testexecution_name if testexecution_name else None
 
     def set_testexecution_desc(self, description: str):
         self.testexecution_desc = description
