@@ -65,10 +65,25 @@ class JiraX(Jira):
         return [Jirakey(issue.get('key')) for issue in issues if issue.get('fields')['summary'] == summary]
 
     def link(self, parent_jira: str, child_jira: str, type="Parents"):
+        """
+        Common Types:
+        Name, Inward, Outward
+        'Blocks', 'is blocked by', 'blocks'
+        'Cloners', 'is cloned by', 'clones'
+        'Defect', 'created by', 'created'
+        'Duplicate', 'is duplicated by', 'duplicates'
+        'Issue split', 'split from', 'split to'
+        'Parents', 'Child', 'Parent'
+        'Problem/Incident', 'is caused by', 'causes'
+        'Relates', 'relates to', 'relates to'
+        'Require', 'required by', 'requires'
+        'Test', 'is tested by', 'tests
+
+        """
         return self.create_issue_link({
             "type": {"name": type},
-            "inwardIssue": {"key": Jirakey(child_jira)},
-            "outwardIssue": {"key": Jirakey(parent_jira)}
+            "inwardIssue": {"key": str(Jirakey(child_jira))},
+            "outwardIssue": {"key": str(Jirakey(parent_jira))}
         })
 
     def _create(self, summary: str, description: str, issue_type: str) -> Jirakey:
